@@ -3,7 +3,6 @@ package attachments
 import (
 	"fmt"
 	"io"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"sync"
@@ -232,6 +231,20 @@ func (u *Uploader) Complete(ctx context.Context, outboxID chat1.OutboxID) {
 	u.clearTempDirFromOutboxID(ctx, outboxID)
 }
 
+func (u *Uploader) clearExpoAudioPaths(ctx context.Context) {
+	if u.G().IsMobileAppType() {
+		var subDir string
+		if libkb.IsAndroid() {
+			subDir = "../../../cache/Audio"
+		} else {
+			subDir = "../AV"
+		}
+		dir := filepath.Join(u.G().GetCacheDir(), subDir)
+		u.Debug(ctx, "clearExpoAudioPaths: clearing current dir: %s", dir)
+		os.RemoveAll(dir)
+	}
+}
+
 func (u *Uploader) clearOldUploaderTempDirs(ctx context.Context, delay time.Duration) {
 	u.Debug(ctx, "clearOldUploaderTempDirs: cleaning in %v", delay)
 	select {
@@ -247,7 +260,9 @@ func (u *Uploader) clearOldUploaderTempDirs(ctx context.Context, delay time.Dura
 		u.Debug(ctx, "clearOldUploaderTempDirs: cleaning: %s", dir)
 		os.RemoveAll(dir)
 	}
-	if !u.G().IsMobileAppType() {
+	if u.G().IsMobileAppType() {
+		u.clearExpoAudioPaths(ctx)
+	} else {
 		dir := u.getUploadTempBaseDir(u.versionUploaderTemps)
 		u.Debug(ctx, "clearOldUploaderTempDirs: clearing current dir: %s", dir)
 		os.RemoveAll(dir)
@@ -258,6 +273,8 @@ func (u *Uploader) clearTempDirFromOutboxID(ctx context.Context, outboxID chat1.
 	dir := u.getUploadTempDir(u.versionUploaderTemps, outboxID)
 	u.Debug(ctx, "clearTempDirFromOutboxID: clearing: %s", dir)
 	os.RemoveAll(dir)
+
+	u.clearExpoAudioPaths(ctx)
 }
 
 func (u *Uploader) Retry(ctx context.Context, outboxID chat1.OutboxID) (res types.AttachmentUploaderResultCb, err error) {
@@ -407,7 +424,7 @@ func (u *Uploader) uploadFile(ctx context.Context, diskLRU *disklru.DiskLRU, dir
 	if err := os.MkdirAll(dir, os.ModePerm); err != nil {
 		return nil, err
 	}
-	f, err = ioutil.TempFile(dir, prefix)
+	f, err = os.CreateTemp(dir, prefix)
 	if err != nil {
 		return nil, err
 	}
@@ -539,7 +556,7 @@ func (u *Uploader) upload(ctx context.Context, uid gregor1.UID, convID chat1.Con
 		uf, err := u.uploadFullFile(ctx, pre.BaseMetadata())
 		if err != nil {
 			u.Debug(bgctx, "upload: failed to create uploaded full file: %s", err)
-			encryptedOut = ioutil.Discard
+			encryptedOut = io.Discard
 			uf = nil
 		} else {
 			defer uf.Close()
@@ -604,7 +621,7 @@ func (u *Uploader) upload(ctx context.Context, uid gregor1.UID, convID chat1.Con
 			up, err := u.uploadPreviewFile(ctx)
 			if err != nil {
 				u.Debug(bgctx, "upload: failed to create uploaded preview file: %s", err)
-				encryptedOut = ioutil.Discard
+				encryptedOut = io.Discard
 				up = nil
 			} else {
 				defer up.Close()
