@@ -347,8 +347,8 @@ func (s *RemoteInboxSource) ReadUnverified(ctx context.Context, uid gregor1.UID,
 }
 
 func (s *RemoteInboxSource) MarkAsRead(ctx context.Context, convID chat1.ConversationID,
-	uid gregor1.UID, msgID *chat1.MessageID) (err error) {
-	defer s.Trace(ctx, &err, "MarkAsRead(%s,%d)", convID, msgID)()
+	uid gregor1.UID, msgID *chat1.MessageID, forceUnread bool) (err error) {
+	defer s.Trace(ctx, &err, "MarkAsRead(%s,%v,%v)", convID, msgID, forceUnread)()
 	if msgID == nil {
 		conv, err := utils.GetUnverifiedConv(ctx, s.G(), uid, convID, types.InboxSourceDataSourceAll)
 		if err != nil {
@@ -360,6 +360,7 @@ func (s *RemoteInboxSource) MarkAsRead(ctx context.Context, convID chat1.Convers
 	if _, err = s.getChatInterface().MarkAsRead(ctx, chat1.MarkAsReadArg{
 		ConversationID: convID,
 		MsgID:          *msgID,
+		ForceUnread:    forceUnread,
 	}); err != nil {
 		return err
 	}
@@ -648,9 +649,10 @@ func (s *HybridInboxSource) markAsReadDeliver(ctx context.Context) (err error) {
 		if _, err := s.getChatInterface().MarkAsRead(ctx, chat1.MarkAsReadArg{
 			ConversationID: rec.ConvID,
 			MsgID:          rec.MsgID,
+			ForceUnread:    rec.ForceUnread,
 		}); err != nil {
-			s.Debug(ctx, "markAsReadDeliver: failed to mark as read: convID: %s msgID: %s err: %s",
-				rec.ConvID, rec.MsgID, err)
+			s.Debug(ctx, "markAsReadDeliver: failed to mark as read: convID: %s msgID: %s forceUnread: %v err: %s",
+				rec.ConvID, rec.MsgID, rec.ForceUnread, err)
 			// check for an immediate failure from the server, and get the attempt out if it fails
 			if berr, ok := err.(DelivererInfoError); ok {
 				if _, ok := berr.IsImmediateFail(); ok {
@@ -860,15 +862,18 @@ func (s *HybridInboxSource) IncrementLocalConvVersion(ctx context.Context, uid g
 }
 
 func (s *HybridInboxSource) MarkAsRead(ctx context.Context, convID chat1.ConversationID,
-	uid gregor1.UID, msgID *chat1.MessageID) (err error) {
-	defer s.Trace(ctx, &err, "MarkAsRead(%s,%d)", convID, msgID)()
+	uid gregor1.UID, msgID *chat1.MessageID, forceUnread bool) (err error) {
+	defer s.Trace(ctx, &err, "MarkAsRead(%s,%d, %v)", convID, msgID, forceUnread)()
 	defer s.maybeNuke(ctx, uid, &convID, &err)
-	// Check local copy to see if we have this convo, and have fully read it. If so, we skip the remote call
-	readRes, err := s.createInbox().GetConversation(ctx, uid, convID)
-	if err == nil && readRes.GetConvID().Eq(convID) &&
-		readRes.Conv.ReaderInfo.ReadMsgid == readRes.Conv.ReaderInfo.MaxMsgid {
-		s.Debug(ctx, "MarkAsRead: conversation fully read: %s, not sending remote call", convID)
-		return nil
+	if !forceUnread {
+		// Check local copy to see if we have this convo, and have fully read
+		// it. If so, we skip the remote call unless
+		readRes, err := s.createInbox().GetConversation(ctx, uid, convID)
+		if err == nil && readRes.GetConvID().Eq(convID) &&
+			readRes.Conv.ReaderInfo.ReadMsgid == readRes.Conv.ReaderInfo.MaxMsgid {
+			s.Debug(ctx, "MarkAsRead: conversation fully read: %s, not sending remote call", convID)
+			return nil
+		}
 	}
 	if msgID == nil {
 		conv, err := utils.GetUnverifiedConv(ctx, s.G(), uid, convID, types.InboxSourceDataSourceAll)
@@ -885,7 +890,7 @@ func (s *HybridInboxSource) MarkAsRead(ctx context.Context, convID chat1.Convers
 			return err
 		}
 	}
-	if err := s.readOutbox.PushRead(ctx, convID, *msgID); err != nil {
+	if err := s.readOutbox.PushRead(ctx, convID, *msgID, forceUnread); err != nil {
 		return err
 	}
 	s.flushMarkAsRead(ctx)
