@@ -10,17 +10,18 @@ build_dir=${BUILD_DIR:-/tmp/keybase}
 
 mkdir -p "$build_dir"
 
-current_date=`date -u +%Y%m%d%H%M%S` # UTC
-commit_short=`git log -1 --pretty=format:%h`
+current_date=$(date -u +%Y%m%d%H%M%S) # UTC
+commit_short=$(git log -1 --pretty=format:%h)
 build="$current_date+$commit_short"
 keybase_build=${KEYBASE_BUILD:-$build}
 tags=${TAGS:-"prerelease production"}
 ldflags="-X github.com/keybase/client/go/libkb.PrereleaseBuild=$keybase_build -s -w"
+arch=${ARCH:-"amd64"}
 
-echo "Building $build_dir/keybase ($keybase_build) with $(go version)"
-(cd $client_dir && go build -a -tags "$tags" -ldflags "$ldflags" -o "$build_dir/keybase" "github.com/keybase/client/go/keybase")
+echo "Building $build_dir/keybase ($keybase_build) with $(go version) on arch: $arch"
+(cd "$client_dir" && GOARCH="$arch" go build -a -tags "$tags" -ldflags "$ldflags" -o "$build_dir/keybase" "github.com/keybase/client/go/keybase")
 
-if [ "$PLATFORM" = "darwin" ]; then
+if [ "$PLATFORM" = "darwin" ] || [ "$PLATFORM" = "darwin-arm64" ]; then
   echo "Signing binary..."
   code_sign_identity="9FC3A5BC09FA2EE307C04060C918486411869B65" # "Developer ID Application: Keybase, Inc. (99229SGT5K)"
   codesign --verbose --force --deep --timestamp --options runtime --sign "$code_sign_identity" "$build_dir/keybase"
@@ -33,5 +34,7 @@ else
   exit 1
 fi
 
-version=`"$build_dir"/keybase version -S`
-echo "Keybase version: $version"
+if [ ! "$PLATFORM" = "darwin-arm64" ]; then # we can't run the arm64 binary on the amd64 build machine!
+  version=$("$build_dir"/keybase version -S)
+  echo "Keybase version: $version"
+fi
