@@ -10,7 +10,7 @@ const enabledCalls = json5.parse(fs.readFileSync(path.join(__dirname, 'enabled-c
 // Sanity check this json file
 Object.keys(enabledCalls).forEach(rpc =>
   Object.keys(enabledCalls[rpc]).forEach(type => {
-    if (!['engineSaga', 'promise', 'incoming'].includes(type)) {
+    if (!['promise', 'incoming', 'engineListener'].includes(type)) {
       console.log(colors.red('ERROR! Invalid enabled call?\n\n '), rpc, type)
       process.exit(1)
     }
@@ -216,14 +216,14 @@ function analyzeMessages(json, project) {
 
     const rpcPromise = isUIMethod ? '' : rpcPromiseGen(methodName, name, false)
     const rpcPromiseType = isUIMethod ? '' : rpcPromiseGen(methodName, name, true)
-    const engineSaga = isUIMethod ? '' : engineSagaGen(methodName, name, false)
-    const engineSagaType = isUIMethod ? '' : engineSagaGen(methodName, name, true)
+    const engineListener = isUIMethod ? '' : engineListenerGen(methodName, name, false)
+    const engineListenerType = isUIMethod ? '' : engineListenerGen(methodName, name, true)
 
     if (rpcPromise.length) {
       project.hasEngine = true
     }
-    if (engineSaga.length) {
-      project.hasEngineSaga = true
+    if (engineListener) {
+      project.hasEngineListener = true
     }
 
     const cleanName = methodName.substring(1, methodName.length - 1)
@@ -232,14 +232,14 @@ function analyzeMessages(json, project) {
     }
 
     // Must be an rpc we use
-    if (rpcPromiseType || engineSagaType || isUIMethod) {
+    if (rpcPromiseType || engineListenerType || isUIMethod) {
       map[methodName] = {
         inParam,
         outParam: outParam === 'null' ? 'void' : outParam,
         rpcPromise,
         rpcPromiseType,
-        engineSaga,
-        engineSagaType,
+        engineListener,
+        engineListenerType,
       }
     }
     return map
@@ -251,13 +251,13 @@ function enabledCall(methodName, type) {
   return enabledCalls[cleanName] && enabledCalls[cleanName][type]
 }
 
-function engineSagaGen(methodName, name, justType) {
-  if (!enabledCall(methodName, 'engineSaga')) {
+function engineListenerGen(methodName, name, justType) {
+  if (!enabledCall(methodName, 'engineListener')) {
     return ''
   }
   return justType
-    ? `declare export function ${name}RpcSaga (p: {params: MessageTypes[${methodName}]['inParam'], incomingCallMap: IncomingCallMapType, customResponseIncomingCallMap?: CustomResponseIncomingCallMap, waitingKey?: WaitingKey}): CallEffect<void, () => void, Array<void>>`
-    : `export const ${name}RpcSaga = (p: {params: MessageTypes[${methodName}]['inParam'], incomingCallMap: IncomingCallMapType, customResponseIncomingCallMap?: CustomResponseIncomingCallMap, waitingKey?: WaitingKey}) => call(getEngineSaga(), {method: ${methodName}, params: p.params, incomingCallMap: p.incomingCallMap, customResponseIncomingCallMap: p.customResponseIncomingCallMap, waitingKey: p.waitingKey})`
+    ? `declare export function ${name}RpcListener (p: {params: MessageTypes[${methodName}]['inParam'], incomingCallMap: IncomingCallMapType, customResponseIncomingCallMap?: CustomResponseIncomingCallMap, waitingKey?: WaitingKey}): CallEffect<void, () => void, Array<void>>`
+    : `export const ${name}RpcListener = (p: {params: MessageTypes[${methodName}]['inParam'], incomingCallMap: IncomingCallMapType, customResponseIncomingCallMap?: CustomResponseIncomingCallMap, waitingKey?: WaitingKey}, listenerApi: ListenerApi) => getEngineListener()({method: ${methodName}, params: p.params, incomingCallMap: p.incomingCallMap, customResponseIncomingCallMap: p.customResponseIncomingCallMap, waitingKey: p.waitingKey}, listenerApi)`
 }
 
 function rpcPromiseGen(methodName, name, justType) {
@@ -419,7 +419,7 @@ function writeActions() {
 function writeAll() {
   const imports = Object.keys(projects)
     .map(
-      p => `import {
+      p => `import type {
   CustomResponseIncomingCallMap as ${p}CustomResponseIncomingCallMap,
   IncomingCallMapType as ${p}IncomingCallMap,
 } from './${projects[p].out}'
@@ -453,25 +453,15 @@ function writeFlow(typeDefs, project) {
 
   const engineImports = [
     project.hasEngine ? 'getEngine as engine' : '',
-    project.hasEngineSaga ? 'getEngineSaga' : '',
+    project.hasEngineListener ? 'getEngineListener, type ListenerApi' : '',
   ]
     .filter(f => f.length)
     .join(', ')
   const engineImport = engineImports.length ? `import {${engineImports}} from '../../engine/require'` : ''
-
-  const sagaImports = [
-    project.hasEngineSaga || project.hasEngine ? 'type Effect' : '',
-    project.hasEngineSaga ? 'call' : '',
-  ]
-    .filter(f => f.length)
-    .join(', ')
-  const sagaImport = sagaImports.length ? `import {${sagaImports}} from 'redux-saga/effects'` : ''
-
   const typePrelude = `/* eslint-disable */
 
 // This file is auto-generated by client/protocol/Makefile.
 ${engineImport}
-${sagaImport}
 ${project.import.map(n => importMap[n] || '').join('\n')}
 ${project.import.map(n => `export {${n}}`).join('\n')}
 export type Bool = boolean
@@ -484,12 +474,15 @@ export type Long = number
 export type String = string
 export type Uint = number
 export type Uint64 = number
-${project.hasEngineSaga || project.hasEngine ? 'type WaitingKey = string | Array<string>' : ''}
+${project.hasEngine ? 'type WaitingKey = string | Array<string>' : ''}
 type SimpleError = {code?: number, desc?: string}
 export type IncomingErrorCallback = (err?: SimpleError | null) => void
 ${
-  project.hasEngineSaga || project.hasEngine
-    ? 'type IncomingReturn = Effect | null | void | false | Array<Effect | null | void | false>'
+  project.hasEngine
+    ? `
+import type {TypedActions} from '../../actions/typed-actions-gen'
+type IncomingReturn = Promise<Array<TypedActions> | TypedActions | false | undefined | void> | Array<TypedActions> | TypedActions | false | undefined | void
+`
     : ''
 }
 
@@ -497,7 +490,7 @@ ${
   const consts = Object.keys(typeDefs.consts).map(k => typeDefs.consts[k])
   const types = Object.keys(typeDefs.types).map(k => typeDefs.types[k])
   const messagePromise = Object.keys(typeDefs.messages).map(k => typeDefs.messages[k].rpcPromise)
-  const messageEngineSaga = Object.keys(typeDefs.messages).map(k => typeDefs.messages[k].engineSaga)
+  const messageEngineListener = Object.keys(typeDefs.messages).map(k => typeDefs.messages[k].engineListener)
   const callMapType = Object.keys(project.incomingMaps).length ? 'IncomingCallMapType' : 'void'
   const incomingMap = `\nexport type IncomingCallMapType = {
     ${Object.keys(project.incomingMaps)
@@ -535,7 +528,7 @@ ${messageTypesData}
     ...[...consts, ...types].sort(),
     incomingMap,
     customResponseIncomingMap,
-    ...[...messagePromise, ...messageEngineSaga].sort(),
+    ...[...messagePromise, ...messageEngineListener].sort(),
   ]
     .filter(Boolean)
     .join('\n')
@@ -562,13 +555,12 @@ function write(typeDefs, project) {
 
 // This file is auto-generated by client/protocol/Makefile.
 // Not enabled: calls need to be turned on in enabled-calls.json
-import {call, CallEffect} from 'redux-saga/effects'
-import {getEngine as engine, getEngineSaga} from '../../engine/require'
+import {getEngine as engine} from '../../engine/require'
 `
   const consts = Object.keys(typeDefs.consts).map(k => typeDefs.consts[k])
   const messagePromise = Object.keys(typeDefs.messages).map(k => typeDefs.messages[k].rpcPromise)
-  const messageEngineSaga = Object.keys(typeDefs.messages).map(k => typeDefs.messages[k].engineSaga)
-  const data = [...consts, ...messagePromise, ...messageEngineSaga].filter(Boolean).sort().join('\n')
+  const messageEngineListener = Object.keys(typeDefs.messages).map(k => typeDefs.messages[k].engineListener)
+  const data = [...consts, ...messagePromise, ...messageEngineListener].filter(Boolean).sort().join('\n')
 
   const toWrite = [typePrelude, data].join('\n')
   const destinationFile = `types/${project.out}` // Only used by prettier so we can set an override in .prettierrc
