@@ -6,16 +6,16 @@ import * as DevicesGen from './devices-gen'
 import * as ProvisionGen from './provision-gen'
 import * as WaitingGen from './waiting-gen'
 import * as RPCTypes from '../constants/types/rpc-gen'
-import * as Saga from '../util/saga'
 import * as Tabs from '../constants/tabs'
 import logger from '../logger'
-import {isMobile} from '../constants/platform'
 import HiddenString from '../util/hidden-string'
-import type {RPCError} from '../util/errors'
-import type * as Container from '../constants/reducer'
+import {RPCError} from '../util/errors'
+import * as Container from '../util/container'
 import {devicesTab as settingsDevicesTab} from '../constants/settings'
 
-const devicesRoot = isMobile ? [Tabs.settingsTab, settingsDevicesTab] : [Tabs.devicesTab, 'devicesRoot']
+const devicesRoot = Container.isMobile
+  ? ([Tabs.settingsTab, settingsDevicesTab] as const)
+  : ([Tabs.devicesTab, 'devicesRoot'] as const)
 
 type ValidCallback =
   | 'keybase.1.gpgUi.selectKey'
@@ -55,13 +55,19 @@ class ProvisioningManager {
   private addingANewDevice: boolean
   private done: boolean = false
   private canceled: boolean = false
+  listenerApi: Container.ListenerApi | undefined
 
   _testing = () => ({
     stashedResponse: this.stashedResponse,
   })
 
-  constructor(addingANewDevice: boolean, _: 'ONLY_CALL_THIS_FROM_HELPER') {
+  constructor(
+    addingANewDevice: boolean,
+    listenerApi: Container.ListenerApi | undefined,
+    _: 'ONLY_CALL_THIS_FROM_HELPER'
+  ) {
     this.addingANewDevice = addingANewDevice
+    this.listenerApi = listenerApi
     ProvisioningManager.singleton = this
   }
 
@@ -89,11 +95,9 @@ class ProvisioningManager {
     }
     this.checkNoStashedResponses()
     this.stashedResponse['keybase.1.provisionUi.chooseDevice'] = response
-    return Saga.put(
-      ProvisionGen.createShowDeviceListPage({
-        devices: (params.devices ?? []).map(d => Constants.rpcDeviceToDevice(d)),
-      })
-    )
+    return ProvisionGen.createShowDeviceListPage({
+      devices: (params.devices ?? []).map(d => Constants.rpcDeviceToDevice(d)),
+    })
   }
 
   submitDeviceSelect = (state: Container.TypedState) => {
@@ -116,30 +120,28 @@ class ProvisioningManager {
   }
 
   // Telling the daemon the other device type when adding a new device
-  chooseDeviceTypeHandler = (
-    _: CustomParam<'keybase.1.provisionUi.chooseDeviceType'>,
-    response: CustomResp<'keybase.1.provisionUi.chooseDeviceType'>
-  ) => {
+  chooseDeviceTypeHandler = (_: unknown, response: CustomResp<'keybase.1.provisionUi.chooseDeviceType'>) => {
     if (this.done) {
       logger.info('ProvisioningManager done, yet chooseDeviceTypeHandler called')
       return
     }
-    return Saga.callUntyped(function* () {
-      const state: Container.TypedState = yield* Saga.selectState()
-      switch (state.provision.codePageOtherDevice.type) {
-        case 'mobile':
-          response.result(RPCTypes.DeviceType.mobile)
-          break
-        case 'desktop':
-          response.result(RPCTypes.DeviceType.desktop)
-          break
-        default:
-          response.error()
-          throw new Error(
-            'Tried to add a device but of unknown type' + state.provision.codePageOtherDevice.type
-          )
-      }
-    })
+    if (!this.listenerApi) {
+      throw new Error('No listener api should be impossible')
+    }
+    const state = this.listenerApi.getState()
+    switch (state.provision.codePageOtherDevice.type) {
+      case 'mobile':
+        response.result(RPCTypes.DeviceType.mobile)
+        break
+      case 'desktop':
+        response.result(RPCTypes.DeviceType.desktop)
+        break
+      default:
+        response.error()
+        throw new Error(
+          'Tried to add a device but of unknown type' + state.provision.codePageOtherDevice.type
+        )
+    }
   }
 
   // Choosing a name for this new device
@@ -153,12 +155,10 @@ class ProvisioningManager {
     }
     this.checkNoStashedResponses()
     this.stashedResponse['keybase.1.provisionUi.PromptNewDeviceName'] = response
-    return Saga.put(
-      ProvisionGen.createShowNewDeviceNamePage({
-        error: params.errorMessage ? new HiddenString(params.errorMessage) : null,
-        existingDevices: params.existingDevices ?? [],
-      })
-    )
+    return ProvisionGen.createShowNewDeviceNamePage({
+      error: params.errorMessage ? new HiddenString(params.errorMessage) : null,
+      existingDevices: params.existingDevices ?? [],
+    })
   }
 
   submitDeviceName = (state: Container.TypedState) => {
@@ -197,12 +197,10 @@ class ProvisioningManager {
     }
     this.checkNoStashedResponses()
     this.stashedResponse['keybase.1.provisionUi.DisplayAndPromptSecret'] = response
-    return Saga.put(
-      ProvisionGen.createShowCodePage({
-        code: new HiddenString(params.phrase),
-        error: params.previousErr ? new HiddenString(params.previousErr) : null,
-      })
-    )
+    return ProvisionGen.createShowCodePage({
+      code: new HiddenString(params.phrase),
+      error: params.previousErr ? new HiddenString(params.previousErr) : null,
+    })
   }
 
   submitTextCode = (state: Container.TypedState) => {
@@ -241,7 +239,7 @@ class ProvisioningManager {
     }
     this.checkNoStashedResponses()
     this.stashedResponse['keybase.1.provisionUi.chooseGPGMethod'] = response
-    return Saga.put(ProvisionGen.createShowGPGPage())
+    return ProvisionGen.createShowGPGPage()
   }
 
   submitGPGMethod = (state: Container.TypedState, action: ProvisionGen.SubmitGPGMethodPayload) => {
@@ -273,10 +271,10 @@ class ProvisioningManager {
     }
     this.checkNoStashedResponses()
     this.stashedResponse['keybase.1.provisionUi.switchToGPGSignOK'] = response
-    return Saga.all([
-      Saga.put(ProvisionGen.createSwitchToGPGSignOnly({importError: params.importError})),
-      Saga.put(ProvisionGen.createShowGPGPage()),
-    ])
+    return [
+      ProvisionGen.createSwitchToGPGSignOnly({importError: params.importError}),
+      ProvisionGen.createShowGPGPage(),
+    ]
   }
 
   submitGPGSignOK = (action: ProvisionGen.SubmitGPGSignOKPayload) => {
@@ -313,9 +311,9 @@ class ProvisioningManager {
 
     switch (params.pinentry.type) {
       case RPCTypes.PassphraseType.passPhrase:
-        return Saga.put(ProvisionGen.createShowPasswordPage({error: error ? new HiddenString(error) : null}))
+        return ProvisionGen.createShowPasswordPage({error: error ? new HiddenString(error) : null})
       case RPCTypes.PassphraseType.paperKey:
-        return Saga.put(ProvisionGen.createShowPaperkeyPage({error: error ? new HiddenString(error) : null}))
+        return ProvisionGen.createShowPaperkeyPage({error: error ? new HiddenString(error) : null})
       default:
         throw new Error('Got confused about password entry. Please send a log to us!')
     }
@@ -349,41 +347,46 @@ class ProvisioningManager {
 
   displaySecretExchanged = () => {
     // special case, we actually aren't waiting when we get this so our count goes negative. This is very unusual and a one-off
-    return Saga.put(
-      WaitingGen.createBatchChangeWaiting({changes: [{increment: true, key: Constants.waitingKey}]})
-    )
+    return WaitingGen.createBatchChangeWaiting({changes: [{increment: true, key: Constants.waitingKey}]})
   }
 
-  getCustomResponseIncomingCallMap = () =>
+  getCustomResponseIncomingCallMap = (): RPCTypes.CustomResponseIncomingCallMap =>
     this.addingANewDevice
-      ? {
-          'keybase.1.provisionUi.DisplayAndPromptSecret': this.displayAndPromptSecretHandler,
-          'keybase.1.provisionUi.chooseDeviceType': this.chooseDeviceTypeHandler,
-        }
-      : {
+      ? ({
+          'keybase.1.provisionUi.DisplayAndPromptSecret': (params, response) =>
+            this.displayAndPromptSecretHandler(params, response),
+          'keybase.1.provisionUi.chooseDeviceType': (params, response) =>
+            this.chooseDeviceTypeHandler(params, response),
+        } as const)
+      : ({
           'keybase.1.gpgUi.selectKey': Constants.cancelOnCallback,
           'keybase.1.loginUi.getEmailOrUsername': Constants.cancelOnCallback,
-          'keybase.1.provisionUi.DisplayAndPromptSecret': this.displayAndPromptSecretHandler,
-          'keybase.1.provisionUi.PromptNewDeviceName': this.promptNewDeviceNameHandler,
-          'keybase.1.provisionUi.chooseDevice': this.chooseDeviceHandler,
-          'keybase.1.provisionUi.chooseGPGMethod': this.chooseGPGMethodHandler,
-          'keybase.1.provisionUi.switchToGPGSignOK': this.switchToGPGSignOKHandler,
-          'keybase.1.secretUi.getPassphrase': this.getPasswordHandler,
-        }
+          'keybase.1.provisionUi.DisplayAndPromptSecret': (params, response) =>
+            this.displayAndPromptSecretHandler(params, response),
+          'keybase.1.provisionUi.PromptNewDeviceName': (params, response) =>
+            this.promptNewDeviceNameHandler(params, response),
+          'keybase.1.provisionUi.chooseDevice': (params, response) =>
+            this.chooseDeviceHandler(params, response),
+          'keybase.1.provisionUi.chooseGPGMethod': (params, response) =>
+            this.chooseGPGMethodHandler(params, response),
+          'keybase.1.provisionUi.switchToGPGSignOK': (params, response) =>
+            this.switchToGPGSignOKHandler(params, response),
+          'keybase.1.secretUi.getPassphrase': (params, response) => this.getPasswordHandler(params, response),
+        } as const)
 
-  getIncomingCallMap = () =>
+  getIncomingCallMap = (): RPCTypes.IncomingCallMapType =>
     this.addingANewDevice
-      ? {
-          'keybase.1.provisionUi.DisplaySecretExchanged': this.displaySecretExchanged,
+      ? ({
+          'keybase.1.provisionUi.DisplaySecretExchanged': () => this.displaySecretExchanged(),
           'keybase.1.provisionUi.ProvisioneeSuccess': ignoreCallback,
           'keybase.1.provisionUi.ProvisionerSuccess': ignoreCallback,
-        }
-      : {
+        } as const)
+      : ({
           'keybase.1.loginUi.displayPrimaryPaperKey': ignoreCallback,
-          'keybase.1.provisionUi.DisplaySecretExchanged': this.displaySecretExchanged,
+          'keybase.1.provisionUi.DisplaySecretExchanged': () => this.displaySecretExchanged(),
           'keybase.1.provisionUi.ProvisioneeSuccess': ignoreCallback,
           'keybase.1.provisionUi.ProvisionerSuccess': ignoreCallback,
-        }
+        } as const)
 
   showCodePage = () =>
     RouteTreeGen.createNavigateAppend({
@@ -412,38 +415,49 @@ class ProvisioningManager {
   }
 }
 
-const makeProvisioningManager = (addingANewDevice: boolean): ProvisioningManager =>
-  new ProvisioningManager(addingANewDevice, 'ONLY_CALL_THIS_FROM_HELPER')
+const makeProvisioningManager = (
+  addingANewDevice: boolean,
+  listenerApi: Container.ListenerApi | undefined
+): ProvisioningManager => new ProvisioningManager(addingANewDevice, listenerApi, 'ONLY_CALL_THIS_FROM_HELPER')
 
 /**
  * We are starting the provisioning process. This is largely controlled by the daemon. We get a callback to show various
  * screens and we stash the result object so we can show the screen. When the submit on that screen is done we find the stashedReponse and respond and wait
  */
-function* startProvisioning(state: Container.TypedState) {
-  yield Saga.put(WaitingGen.createClearWaiting({key: Constants.waitingKey}))
-  const manager = makeProvisioningManager(false)
+const startProvisioning = async (
+  state: Container.TypedState,
+  _a: unknown,
+  listenerApi: Container.ListenerApi
+) => {
+  listenerApi.dispatch(WaitingGen.createClearWaiting({key: Constants.waitingKey}))
+  const manager = makeProvisioningManager(false, listenerApi)
   try {
     const username = state.provision.username
     if (!username) {
       return
     }
 
-    yield RPCTypes.loginLoginRpcSaga({
-      customResponseIncomingCallMap: ProvisioningManager.getSingleton().getCustomResponseIncomingCallMap(),
-      incomingCallMap: ProvisioningManager.getSingleton().getIncomingCallMap(),
-      params: {
-        clientType: RPCTypes.ClientType.guiMain,
-        deviceName: '',
-        deviceType: isMobile ? 'mobile' : 'desktop',
-        doUserSwitch: true,
-        paperKey: '',
-        username: username,
+    await RPCTypes.loginLoginRpcListener(
+      {
+        customResponseIncomingCallMap: ProvisioningManager.getSingleton().getCustomResponseIncomingCallMap(),
+        incomingCallMap: ProvisioningManager.getSingleton().getIncomingCallMap(),
+        params: {
+          clientType: RPCTypes.ClientType.guiMain,
+          deviceName: '',
+          deviceType: Container.isMobile ? 'mobile' : 'desktop',
+          doUserSwitch: true,
+          paperKey: '',
+          username: username,
+        },
+        waitingKey: Constants.waitingKey,
       },
-      waitingKey: Constants.waitingKey,
-    })
+      listenerApi
+    )
     ProvisioningManager.getSingleton().setDone('provision call done w/ success')
-  } catch (finalError_) {
-    const finalError = finalError_ as RPCError
+  } catch (finalError) {
+    if (!(finalError instanceof RPCError)) {
+      return
+    }
     manager.setDone(
       'startProvisioning call done w/ error ' + (finalError ? finalError.message : ' unknown error')
     )
@@ -467,36 +481,41 @@ function* startProvisioning(state: Container.TypedState) {
     switch (finalError.code) {
       case RPCTypes.StatusCode.scnotfound:
       case RPCTypes.StatusCode.scbadusername:
-        yield Saga.put(ProvisionGen.createShowInlineError({inlineError: finalError}))
+        listenerApi.dispatch(ProvisionGen.createShowInlineError({inlineError: finalError}))
         break
       default:
-        yield Saga.put(ProvisionGen.createShowFinalErrorPage({finalError, fromDeviceAdd: false}))
+        listenerApi.dispatch(ProvisionGen.createShowFinalErrorPage({finalError, fromDeviceAdd: false}))
         break
     }
   } finally {
-    yield Saga.put(WaitingGen.createClearWaiting({key: Constants.waitingKey}))
-    yield Saga.put(ProvisionGen.createProvisionDone())
+    listenerApi.dispatch(WaitingGen.createClearWaiting({key: Constants.waitingKey}))
+    listenerApi.dispatch(ProvisionGen.createProvisionDone())
   }
 }
 
-function* addNewDevice() {
+const addNewDevice = async (_s: unknown, _a: unknown, listenerApi: Container.ListenerApi) => {
   // Make a new handler each time.
-  yield Saga.put(WaitingGen.createClearWaiting({key: Constants.waitingKey}))
-  const manager = makeProvisioningManager(true)
+  listenerApi.dispatch(WaitingGen.createClearWaiting({key: Constants.waitingKey}))
+  const manager = makeProvisioningManager(true, listenerApi)
   try {
-    yield RPCTypes.deviceDeviceAddRpcSaga({
-      customResponseIncomingCallMap: ProvisioningManager.getSingleton().getCustomResponseIncomingCallMap(),
-      incomingCallMap: ProvisioningManager.getSingleton().getIncomingCallMap(),
-      params: undefined,
-      waitingKey: Constants.waitingKey,
-    })
+    await RPCTypes.deviceDeviceAddRpcListener(
+      {
+        customResponseIncomingCallMap: ProvisioningManager.getSingleton().getCustomResponseIncomingCallMap(),
+        incomingCallMap: ProvisioningManager.getSingleton().getIncomingCallMap(),
+        params: undefined,
+        waitingKey: Constants.waitingKey,
+      },
+      listenerApi
+    )
     ProvisioningManager.getSingleton().setDone('add device success')
     // Now refresh and nav back
-    yield Saga.put(DevicesGen.createLoad())
-    yield Saga.put(RouteTreeGen.createNavigateAppend({path: devicesRoot}))
-    yield Saga.put(RouteTreeGen.createClearModals())
-  } catch (finalError_) {
-    const finalError = finalError_ as RPCError
+    listenerApi.dispatch(DevicesGen.createLoad())
+    listenerApi.dispatch(RouteTreeGen.createNavigateAppend({path: devicesRoot}))
+    listenerApi.dispatch(RouteTreeGen.createClearModals())
+  } catch (finalError) {
+    if (!(finalError instanceof RPCError)) {
+      return
+    }
     manager.setDone('addNewDevice call done w/ error ' + (finalError ? finalError.message : ' unknown error'))
 
     if (ProvisioningManager.getSingleton() !== manager) {
@@ -511,11 +530,11 @@ function* addNewDevice() {
       return
     }
 
-    yield Saga.put(ProvisionGen.createShowFinalErrorPage({finalError, fromDeviceAdd: true}))
+    listenerApi.dispatch(ProvisionGen.createShowFinalErrorPage({finalError, fromDeviceAdd: true}))
     logger.error(`Provision -> Add device error: ${finalError.message}`)
   } finally {
-    yield Saga.put(WaitingGen.createClearWaiting({key: Constants.waitingKey}))
-    yield Saga.put(ProvisionGen.createProvisionDone())
+    listenerApi.dispatch(WaitingGen.createClearWaiting({key: Constants.waitingKey}))
+    listenerApi.dispatch(ProvisionGen.createProvisionDone())
   }
 }
 
@@ -528,7 +547,7 @@ const submitTextCode = (state: Container.TypedState) =>
   ProvisioningManager.getSingleton().submitTextCode(state)
 const submitGPGMethod = (state: Container.TypedState, action: ProvisionGen.SubmitGPGMethodPayload) =>
   ProvisioningManager.getSingleton().submitGPGMethod(state, action)
-const submitGPGSignOK = (action: ProvisionGen.SubmitGPGSignOKPayload) =>
+const submitGPGSignOK = (_: unknown, action: ProvisionGen.SubmitGPGSignOKPayload) =>
   ProvisioningManager.getSingleton().submitGPGSignOK(action)
 const submitPasswordOrPaperkey = (
   state: Container.TypedState,
@@ -564,10 +583,10 @@ const showPaperkeyPage = (state: Container.TypedState) =>
   !state.provision.error.stringValue() &&
   RouteTreeGen.createNavigateAppend({path: ['paperkey'], replace: true})
 
-const showFinalErrorPage = (action: ProvisionGen.ShowFinalErrorPagePayload) => {
-  const parentPath = action.payload.fromDeviceAdd ? devicesRoot : ['login']
+const showFinalErrorPage = (_: unknown, action: ProvisionGen.ShowFinalErrorPagePayload) => {
+  const parentPath = action.payload.fromDeviceAdd ? devicesRoot : (['login'] as const)
   const replace = !action.payload.fromDeviceAdd
-  const path = ['error']
+  const path = ['error'] as const
   return [
     ...(action.payload.fromDeviceAdd ? [RouteTreeGen.createClearModals()] : []),
     RouteTreeGen.createNavigateAppend({path: [...parentPath, ...path], replace}),
@@ -590,7 +609,7 @@ const showUsernameEmailPage = async (
   })
 }
 
-const forgotUsername = async (action: ProvisionGen.ForgotUsernamePayload) => {
+const forgotUsername = async (_: unknown, action: ProvisionGen.ForgotUsernamePayload) => {
   if (action.payload.email) {
     try {
       await RPCTypes.accountRecoverUsernameWithEmailRpcPromise(
@@ -598,8 +617,10 @@ const forgotUsername = async (action: ProvisionGen.ForgotUsernamePayload) => {
         Constants.forgotUsernameWaitingKey
       )
       return ProvisionGen.createForgotUsernameResult({result: 'success'})
-    } catch (error_) {
-      const error = error_ as RPCError
+    } catch (error) {
+      if (!(error instanceof RPCError)) {
+        return
+      }
       return ProvisionGen.createForgotUsernameResult({
         result: Constants.decodeForgotUsernameError(error),
       })
@@ -612,8 +633,10 @@ const forgotUsername = async (action: ProvisionGen.ForgotUsernamePayload) => {
         Constants.forgotUsernameWaitingKey
       )
       return ProvisionGen.createForgotUsernameResult({result: 'success'})
-    } catch (error_) {
-      const error = error_ as RPCError
+    } catch (error) {
+      if (!(error instanceof RPCError)) {
+        return
+      }
       return ProvisionGen.createForgotUsernameResult({
         result: Constants.decodeForgotUsernameError(error),
       })
@@ -623,55 +646,48 @@ const forgotUsername = async (action: ProvisionGen.ForgotUsernamePayload) => {
   return null
 }
 
-function* backToDeviceList(_: Container.TypedState, action: ProvisionGen.BackToDeviceListPayload) {
+const backToDeviceList = async (
+  _: Container.TypedState,
+  action: ProvisionGen.BackToDeviceListPayload,
+  listenerApi: Container.ListenerApi
+) => {
   const cancelled = ProvisioningManager.getSingleton().maybeCancelProvision()
   if (cancelled) {
     // must wait for previous session to close
-    yield Saga.take(ProvisionGen.provisionDone)
+    await listenerApi.take(action => action.type === ProvisionGen.provisionDone)
   }
-  yield Saga.put(ProvisionGen.createSubmitUsername({username: action.payload.username}))
+  listenerApi.dispatch(ProvisionGen.createSubmitUsername({username: action.payload.username}))
 }
 
-function* provisionSaga() {
+const initProvision = () => {
   // Always ensure we have one live
-  makeProvisioningManager(false)
+  makeProvisioningManager(false, undefined)
 
   // Start provision
-  yield* Saga.chainGenerator<ProvisionGen.SubmitUsernamePayload>(
-    ProvisionGen.submitUsername,
-    startProvisioning
-  )
-  yield* Saga.chainGenerator<ProvisionGen.AddNewDevicePayload>(ProvisionGen.addNewDevice, addNewDevice)
+  Container.listenAction(ProvisionGen.submitUsername, startProvisioning)
+  Container.listenAction(ProvisionGen.addNewDevice, addNewDevice)
 
   // Submits
-  yield* Saga.chainAction2(ProvisionGen.submitDeviceSelect, submitDeviceSelect)
-  yield* Saga.chainAction2(ProvisionGen.submitDeviceName, submitDeviceName)
-  yield* Saga.chainAction2(ProvisionGen.submitTextCode, submitTextCode)
-  yield* Saga.chainAction2(ProvisionGen.submitGPGMethod, submitGPGMethod)
-  yield* Saga.chainAction(ProvisionGen.submitGPGSignOK, submitGPGSignOK)
-  yield* Saga.chainAction2(
-    [ProvisionGen.submitPassword, ProvisionGen.submitPaperkey],
-    submitPasswordOrPaperkey
-  )
+  Container.listenAction(ProvisionGen.submitDeviceSelect, submitDeviceSelect)
+  Container.listenAction(ProvisionGen.submitDeviceName, submitDeviceName)
+  Container.listenAction(ProvisionGen.submitTextCode, submitTextCode)
+  Container.listenAction(ProvisionGen.submitGPGMethod, submitGPGMethod)
+  Container.listenAction(ProvisionGen.submitGPGSignOK, submitGPGSignOK)
+  Container.listenAction([ProvisionGen.submitPassword, ProvisionGen.submitPaperkey], submitPasswordOrPaperkey)
 
   // Screens
-  yield* Saga.chainAction2(ProvisionGen.startProvision, showUsernameEmailPage)
-  yield* Saga.chainAction2(ProvisionGen.showDeviceListPage, showDeviceListPage)
-  yield* Saga.chainAction2(ProvisionGen.showNewDeviceNamePage, showNewDeviceNamePage)
-  yield* Saga.chainAction2(ProvisionGen.showCodePage, showCodePage)
-  yield* Saga.chainAction2(ProvisionGen.showGPGPage, showGPGPage)
-  yield* Saga.chainAction2(ProvisionGen.showPasswordPage, showPasswordPage)
-  yield* Saga.chainAction2(ProvisionGen.showPaperkeyPage, showPaperkeyPage)
-  yield* Saga.chainAction(ProvisionGen.showFinalErrorPage, showFinalErrorPage)
-  yield* Saga.chainAction(ProvisionGen.forgotUsername, forgotUsername)
+  Container.listenAction(ProvisionGen.startProvision, showUsernameEmailPage)
+  Container.listenAction(ProvisionGen.showDeviceListPage, showDeviceListPage)
+  Container.listenAction(ProvisionGen.showNewDeviceNamePage, showNewDeviceNamePage)
+  Container.listenAction(ProvisionGen.showCodePage, showCodePage)
+  Container.listenAction(ProvisionGen.showGPGPage, showGPGPage)
+  Container.listenAction(ProvisionGen.showPasswordPage, showPasswordPage)
+  Container.listenAction(ProvisionGen.showPaperkeyPage, showPaperkeyPage)
+  Container.listenAction(ProvisionGen.showFinalErrorPage, showFinalErrorPage)
+  Container.listenAction(ProvisionGen.forgotUsername, forgotUsername)
 
-  yield* Saga.chainAction2(ProvisionGen.cancelProvision, maybeCancelProvision)
-  yield* Saga.chainGenerator(ProvisionGen.backToDeviceList, backToDeviceList)
+  Container.listenAction(ProvisionGen.cancelProvision, maybeCancelProvision)
+  Container.listenAction(ProvisionGen.backToDeviceList, backToDeviceList)
 }
 
-export const _testing: any = {
-  makeProvisioningManager,
-  maybeCancelProvision,
-}
-
-export default provisionSaga
+export default initProvision
