@@ -1,4 +1,4 @@
-import * as Types from '../../../constants/types/chat2'
+import type * as Types from '../../../constants/types/chat2'
 import * as Container from '../../../util/container'
 import ThreadLoadStatus from '.'
 
