@@ -1,12 +1,12 @@
 import * as React from 'react'
-import ReAnimated, {withRepeat, useSharedValue, withTiming, useAnimatedStyle, withDelay} from './reanimated'
 import * as Styles from '../styles'
+import Animated, {withRepeat, useSharedValue, withTiming, useAnimatedStyle, withDelay} from './reanimated'
 
-const LoadingLine = React.memo(() => {
+const LoadingLine = React.memo(function LoadingLine() {
   const opacity = useSharedValue(0)
   opacity.value = withDelay(1000, withRepeat(withTiming(1, {duration: 600}), -1, true))
   const animatedStyle = useAnimatedStyle(() => ({opacity: opacity.value}))
-  return <ReAnimated.View style={[styles.line, animatedStyle]} />
+  return <Animated.View style={[styles.line, animatedStyle]} />
 })
 
 const styles = Styles.styleSheetCreate(
