@@ -29,6 +29,7 @@ import logger from '../../logger'
 import {assetRoot, htmlPrefix} from './html-root.desktop'
 import * as RPCTypes from '../../constants/types/rpc-gen'
 import type {Action} from '../app/ipctypes'
+import {makeEngine} from '../../engine'
 import {showDevTools, skipSecondaryDevtools, allowMultipleInstances} from '../../local-debug.desktop'
 
 const {env} = KB2.constants
@@ -98,7 +99,7 @@ const focusSelfOnAnotherInstanceLaunching = (commandLine: Array<string>) => {
     //
     // Windows looks like:
     // ["Keybase.exe", "--somearg", "--someotherarg", "actuallink"]
-    for (let link of commandLine.slice(1)) {
+    for (const link of commandLine.slice(1)) {
       if (isRelevantDeepLink(link)) {
         mainWindowDispatch(DeeplinksGen.createLink({link}))
         return
@@ -174,6 +175,17 @@ const handleCrashes = () => {
   })
 }
 
+const stopNav = () => {
+  Electron.app.on('web-contents-created', (_, contents) => {
+    contents.on('will-navigate', event => {
+      event.preventDefault()
+    })
+    contents.setWindowOpenHandler(() => {
+      return {action: 'deny'}
+    })
+  })
+}
+
 // On Windows and Linux startup, open-file and open-url arguments will be
 // passed via process.argv instead of via Electron event arguments.
 const getStartupProcessArgs = () => {
@@ -246,7 +258,7 @@ const willFinishLaunching = () => {
 let menubarWindowID = 0
 
 const remoteURL = (windowComponent: string, windowParam: string) =>
-  `${htmlPrefix}${assetRoot}${windowComponent}${__DEV__ ? '.dev' : ''}.html?param=${windowParam}`
+  `${htmlPrefix}${assetRoot}${windowComponent}${__FILE_SUFFIX__}.html?param=${windowParam}`
 
 const findRemoteComponent = (windowComponent: string, windowParam: string) => {
   const url = remoteURL(windowComponent, windowParam)
@@ -356,31 +368,24 @@ const plumbEvents = () => {
     mainWindowDispatch(ConfigGen.createSetSystemDarkMode({dark: Electron.nativeTheme.shouldUseDarkColors}))
   })
 
-  Electron.powerMonitor.on('suspend', () => {
-    RPCTypes.appStatePowerMonitorEventRpcPromise({event: 'suspend'})
-      .then(() => {})
-      .catch(() => {})
-  })
-  Electron.powerMonitor.on('resume', () => {
-    RPCTypes.appStatePowerMonitorEventRpcPromise({event: 'resume'})
-      .then(() => {})
-      .catch(() => {})
-  })
-  Electron.powerMonitor.on('shutdown', () => {
-    RPCTypes.appStatePowerMonitorEventRpcPromise({event: 'shutdown'})
-      .then(() => {})
-      .catch(() => {})
-  })
-  Electron.powerMonitor.on('lock-screen', () => {
-    RPCTypes.appStatePowerMonitorEventRpcPromise({event: 'lock-screen'})
-      .then(() => {})
-      .catch(() => {})
-  })
-  Electron.powerMonitor.on('unlock-screen', () => {
-    RPCTypes.appStatePowerMonitorEventRpcPromise({event: 'unlock-screen'})
-      .then(() => {})
-      .catch(() => {})
-  })
+  // this crashes on newer electron, unclear why
+  if (!isLinux) {
+    Electron.powerMonitor.on('suspend', () => {
+      mainWindowDispatch(ConfigGen.createPowerMonitorEvent({event: 'suspend'}))
+    })
+    Electron.powerMonitor.on('resume', () => {
+      mainWindowDispatch(ConfigGen.createPowerMonitorEvent({event: 'resume'}))
+    })
+    Electron.powerMonitor.on('shutdown', () => {
+      mainWindowDispatch(ConfigGen.createPowerMonitorEvent({event: 'shutdown'}))
+    })
+    Electron.powerMonitor.on('lock-screen', () => {
+      mainWindowDispatch(ConfigGen.createPowerMonitorEvent({event: 'lock-screen'}))
+    })
+    Electron.powerMonitor.on('unlock-screen', () => {
+      mainWindowDispatch(ConfigGen.createPowerMonitorEvent({event: 'unlock-screen'}))
+    })
+  }
 
   Electron.ipcMain.handle('KBdispatchAction', (_: any, action: any) => {
     mainWindow?.webContents.send('KBdispatchAction', action)
@@ -435,8 +440,17 @@ const plumbEvents = () => {
     }
   }
 
+  // we use this engine to proxy calls to the service from the renderer
+  const nodeEngine = makeEngine(mainWindowDispatch)
+
   Electron.ipcMain.handle('KBkeybase', async (event, action: Action) => {
     switch (action.type) {
+      case 'engineSend': {
+        const {buf} = action.payload
+        // @ts-ignore reaching into internals here
+        nodeEngine._rpcClient.transport.send(buf)
+        return
+      }
       case 'uninstallDokan': {
         return new Promise<void>(resolve => {
           try {
@@ -607,6 +621,30 @@ const plumbEvents = () => {
           return false
         }
       }
+      case 'showContextMenu': {
+        const {url} = action.payload
+        const win = Electron.BrowserWindow.fromWebContents(event.sender)
+        if (!win) return
+        const menu = Electron.Menu.buildFromTemplate([
+          {
+            click: () => {
+              Electron.clipboard.writeText(url)
+            },
+            label: 'Copy URL',
+          },
+          {
+            click: () => {
+              Electron.shell
+                .openExternal(url)
+                .then(() => {})
+                .catch(() => {})
+            },
+            label: 'Open in browser',
+          },
+        ])
+        menu.popup({window: win})
+        return
+      }
       case 'showInactive': {
         Electron.BrowserWindow.fromWebContents(event.sender)?.showInactive()
         return
@@ -692,6 +730,9 @@ const plumbEvents = () => {
         break
       case 'appStartedUp':
         appStartedUp = true
+        // tell mainwindow we're connected
+        nodeEngine.listenersAreReady()
+
         if (menubarWindowID) {
           mainWindowDispatch(ConfigGen.createUpdateMenubarWindowID({id: menubarWindowID}))
           // reset it
@@ -743,10 +784,10 @@ const plumbEvents = () => {
           show: false, // Start hidden and show when we actually get props
           titleBarStyle: 'customButtonsOnHover' as const,
           webPreferences: {
-            contextIsolation: false,
-            nodeIntegration: true,
+            contextIsolation: true,
+            nodeIntegration: false,
             nodeIntegrationInWorker: false,
-            preload: `${assetRoot}preload${__DEV__ ? '.dev' : ''}.bundle.js`,
+            preload: `${assetRoot}preload${__FILE_SUFFIX__}.bundle.js`,
           },
           ...action.payload.windowOpts,
         }
@@ -789,6 +830,7 @@ const plumbEvents = () => {
 
 const start = () => {
   handleCrashes()
+  stopNav()
   installCrashReporter()
 
   if (appShouldDieOnStartup()) {
