@@ -1,7 +1,7 @@
 import * as React from 'react'
 import * as Styles from '../../../styles'
 import Rm from 'react-measure'
-import {Props} from '.'
+import type {Props} from '.'
 
 class Measure extends React.Component<Props, {width: number}> {
   _width = 0
