@@ -6,8 +6,8 @@ import QRImage from './qr-image'
 import QRScan from './qr-scan/container'
 import {isAndroid} from '../../constants/platform'
 import Troubleshooting from '../troubleshooting'
-import * as Types from '../../constants/types/provision'
-import * as DeviceTypes from '../../constants/types/devices'
+import type * as Types from '../../constants/types/provision'
+import type * as DeviceTypes from '../../constants/types/devices'
 
 export type DeviceType = 'mobile' | 'desktop'
 export type Tab = 'QR' | 'enterText' | 'viewText'
