@@ -1,4 +1,4 @@
-import React from 'react'
+import * as React from 'react'
 import * as Container from '../../util/container'
 import * as FsGen from '../../actions/fs-gen'
 
