@@ -1,4 +1,4 @@
-import React from 'react'
+import * as React from 'react'
 
 function renderElementOrComponentOrNot(
   item: React.ComponentType<any> | React.ReactElement | null | undefined
@@ -7,7 +7,7 @@ function renderElementOrComponentOrNot(
     if (React.isValidElement(item)) {
       return item
     } else {
-      return React.createElement(item)
+      return React.createElement(item as any)
     }
   }
   return undefined
