@@ -3,12 +3,12 @@ import * as WalletsGen from '../../actions/wallets-gen'
 import * as RouteTreeGen from '../../actions/route-tree-gen'
 import * as Container from '../../util/container'
 
-type OwnProps = Container.RouteProps<'sendReceiveForm'>
+// type OwnProps = Container.RouteProps<'sendReceiveForm'>
 
 export default Container.connect(
   state => ({isRequest: state.wallets.building.isRequest}),
-  (dispatch, ownProps: OwnProps) => {
-    const isAdvanced = ownProps.route.params?.isAdvanced ?? false
+  (dispatch /*, ownProps: OwnProps*/) => {
+    const isAdvanced = /*ownProps.route.params?.isAdvanced ?? */ false
     return {
       onBack: isAdvanced
         ? () => dispatch(RouteTreeGen.createNavigateUp())
@@ -18,8 +18,8 @@ export default Container.connect(
       onClose: () => dispatch(WalletsGen.createAbandonPayment()),
     }
   },
-  ({isRequest}, {onBack, onClose}, ownProps) => ({
-    isAdvanced: ownProps.route.params?.isAdvanced ?? false,
+  ({isRequest}, {onBack, onClose} /*, ownProps*/) => ({
+    isAdvanced: /*ownProps.route.params?.isAdvanced ?? */ false,
     isRequest,
     onBack,
     onClose,
